/* COPYRIGHT (c) J.Mourer */

/* satpos calculates azimuth and angle of elevation for geosationary satellite */

/*
Leeuwarden:
Longitude: 5.80
Latitude: 53.2
*/



#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "satpos.h"


int select_satellite(double *sat)
{
int a;
double Orb[] = {60, 13, 13, 7, -4, -6, -27.5};

fprintf(stdout, "Which satellite?\n");
fprintf(stdout, "1 = INTELSAT V F1/7 (FRG)           +60 deg E\n");
fprintf(stdout, "2 = EUTELSAT 1 F-1 (ECS-1)          +13 deg E\n");
fprintf(stdout, "3 = HOTBIRD 2 Widebeam              +13 deg E\n");
fprintf(stdout, "4 = EUTELSAT 1 F-2 (ECS-2)           +7 deg E\n");
fprintf(stdout, "5 = INTELSAT IV A F2 (NORDIC-1)      -4 deg W\n");      
fprintf(stdout, "6 = TELECOM F-1     (F)              -8 deg W (not in CSS band)\n");
fprintf(stdout, "7 = INTELSAT V F4 (UK/US)           -27.5 deg W\n");
fprintf(stdout, "8 = other satellite\n");

fprintf(stdout, "select 1-8\n");
fscanf(stdin, "%d", &a);

if( (a >= 1) && (a <= 7) )
	{
	*sat = Orb[a - 1];
	return 1;
	}
else if(a == 8)
	{
	fprintf(stdout, "Orbital position of satellite? ");
	fscanf(stdin, "%lf", sat);
	fprintf(stdout, "\n");
	return 1;
	}
else
	{
	fprintf(stdout,  "Invalid input\n");
	return 0;
	}
return 0;
}


int main(int argc, char **argv)
{
double H;
double R;
double ALT;
double B, LO, LA, SAT, AZI, ELE;
int i, n;
double da;

/* rad degrees conversion */
H = 180.0 / PI;

R = 6371.0;
ALT = 35822.0;

fprintf(stdout, "\nPanteltje (c) satpos-0.9 \n\n");

while(1)
	{
	fprintf(stdout, "\n\n");
	fprintf(stdout,\
	"*Longitude and orbit position WEST of Greenwich: PRECEDE BY MINUS SIGN *\n");

	fprintf(stdout, "Longitude of location? ");
	fscanf(stdin, "%lf", &LO);

	fprintf(stdout, "Latitude of location? ");
	fscanf(stdin, "%lf", &LA);

/*
fprintf(stdout,\
"This should give for Intelsat (UK/US):
Azimuth 205 degrees, 25 degrees west of south.
Elevation 26 degrees.\n");

LO = -6.5;
LA = 54;
SAT = -27.5;
*/

	/* Ask user to select a satellite */
	while(! select_satellite(&SAT) ){}

	B = LO - SAT;

	AZI = 180.0 + (H * atan2( tan(B / H), sin(LA / H) ) );
	AZI += .5;

	fprintf(stdout, "\n");
	fprintf(stdout, "Azimuth=%.2f degrees, \n", AZI);
	if(AZI == 180) fprintf(stdout, "Straigt South\n");
	else if(AZI < 180)
		{
		fprintf(stdout,\
		"%.2f degrees East of South\n",\
		180.0 - AZI);
		}
	else if(AZI > 180)
		{
		fprintf(stdout,\
		"%.2f degrees West of South\n",\
		AZI - 180.0);
		}

	ELE =\
	H * atan2(\
	( cos(LA / H) * cos(B / H) ) - (R / (R + ALT) ), \
	sqrt( 1 - (cos(LA / H) * cos(LA / H) * cos(B / H) * cos(B / H) ) )\
	);

	if(ELE < 1)
		{
		fprintf(stdout, "Satellite below horizon\n");
		}

	fprintf(stdout, "Elevation = %.2f degrees\n", ELE + .5);
	}/* end while input */

exit(0);
} /* end function main */

